# #3

### General Details

Run Date: 2021-02-05 15:40:09
Period: 2021-02-05 15:40:09 - 2021-02-05 15:42:09
Run Duration: 2 minutes, 0 second
Status: FAILED
Author: Guillaume Bert

### Description/Conclusion

### Workload Characteristics

Max Running Users:
Average Hits per Second: 239.12138
Total Hits: 14524
Total Passed Transactions per Second: 119.49827
Total Transactions (Success): 152
Total Transactions (Failed): 14205

### Transactions

Name | Count | TPS | Min Dur | Avg Dur | Max Dur | Total | Success | Fail | p50 | p90 | p95 | p99
kamoulox \ Actions \ transaction_no_sla | 3592 | 29.897 | 0.083 | 0.106 | 0.398 | 3592 | 41 | 3551 | 0.099 | 0.13 | 0.16 | 0.206
kamoulox \ Actions \ transaction_sla_failed | 3588 | 29.864 | 0.058 | 0.075 | 0.436 | 3588 | 38 | 3550 | 0.07 | 0.09 | 0.113 | 0.15
kamoulox \ Actions \ transaction_sla_passed | 3586 | 29.848 | 0.058 | 0.075 | 0.335 | 3586 | 32 | 3554 | 0.07 | 0.091 | 0.116 | 0.161
kamoulox \ Actions \ transaction_sla_warning | 3591 | 29.889 | 0.058 | 0.075 | 0.401 | 3591 | 41 | 3550 | 0.07 | 0.09 | 0.111 | 0.156

### Ext. Data

No external data in this test.

### Running Vitrual Users

### Hits per Second